# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import ComplianceECM

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataStorageECM.ComplianceConfiguration

class ComplianceConfigurationEdit(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.ComplianceUI.IComplianceConfigurationEdit,
):  # Class
    def __init__(self, compliance: ComplianceECM) -> None: ...

    CommandPrivilegePrefix: str = ...  # static # readonly
    PreviousPrivilegePrefix: str = ...  # static # readonly
    PrivilegeGroupName: str = ...  # static # readonly

    CanEditRoles: bool  # readonly
    ComplianceECM: ComplianceECM  # readonly

    def Save(
        self,
        config: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration,
    ) -> None: ...
    def Load(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration
    ): ...
    def ResetToDefault(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ComplianceConfiguration
    ): ...
    def PreprocessNewRoleName(self, roleName: str) -> str: ...
    def GetAvailableRoles(self) -> List[str]: ...
    def ConvertPrivilegeName(self, commandName: str) -> str: ...
    def Dispose(self) -> None: ...
    def Run(self, args: List[str]) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .DataAccess import (
    LibraryAccessBase,
    LibraryAccessReportSearch,
    SearchConditions,
    SuggestedConversionType,
)
from .Utils import CompoundKey, SpectrumKey

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands

class AppContext(
    Agilent.MassSpectrometry.CommandModel.Model.ICommandHistory, System.IDisposable
):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...

    Compliance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance
    )  # readonly
    Format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat  # readonly
    IsCommandRunning: bool  # readonly
    IsDirty: bool  # readonly
    IsOpen: bool  # readonly
    IsReadOnly: bool  # readonly
    IsScriptRunning: bool  # readonly
    LibraryAccess: LibraryAccessBase  # readonly
    LibraryName: str  # readonly
    LockObject: Any  # readonly

    def Search(
        self,
        conditions: SearchConditions,
        reportSearch: LibraryAccessReportSearch,
        abort: System.Threading.WaitHandle,
    ) -> None: ...
    def CreateLibrary(
        self, path: str, format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat
    ) -> None: ...
    def ConvertLibrary(
        self,
        infoType: Agilent.MassSpectrometry.DataAnalysis.LibraryRTInfoType,
        destination: str,
    ) -> None: ...
    def CloseLibrary(self) -> None: ...
    def ClearSearch(self) -> None: ...
    def SaveAs(
        self,
        library: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        conversion: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.ConversionType,
    ) -> None: ...
    def Dispose(self) -> None: ...
    def OpenLibrary(
        self,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        revisionNumber: str,
        readOnly: bool,
    ) -> None: ...
    def RunScript(
        self,
        script: System.IO.TextReader,
        customStub: System.MarshalByRefObject,
        debug: bool,
        language: str,
        referenceAssemblies: List[str],
        imports: List[str],
    ) -> None: ...
    def Save(self) -> None: ...

    CommandEnd: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandEventArgs
    ]  # Event
    CommandStart: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandEventArgs
    ]  # Event
    CompoundCountChanged: System.EventHandler  # Event
    CompoundPropertiesChanged: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundPropertiesChangedEventArgs
    ]  # Event
    ConversionSuggested: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.ConversionSuggestedEventArgs
    ]  # Event
    LibraryClosed: System.EventHandler  # Event
    LibraryClosing: System.EventHandler  # Event
    LibraryCreated: System.EventHandler  # Event
    LibraryCreating: System.EventHandler  # Event
    LibraryOpened: System.EventHandler  # Event
    LibraryOpening: System.EventHandler  # Event
    LibraryPropertiesChanged: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.LibraryPropertiesChangedEventArgs
    ]  # Event
    SpectrumCountChanged: System.EventHandler  # Event
    SpectrumPropertiesChanged: System.EventHandler[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumPropertiesChangedEventArgs
    ]  # Event

class CalcMonoisotopicMass(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compounds: List[CompoundKey],
        species: str,
        replace: bool,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class CloseLibrary(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

    IsDirtyCommand: bool  # readonly
    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class CommandBase(
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
    Agilent.MassSpectrometry.CommandModel.CommandBase,
):  # Class
    Context: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext
    )  # readonly
    IsDirtyCommand: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

class CommandEventArgs(System.EventArgs):  # Class
    def __init__(
        self,
        command: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
        ex: System.Exception,
    ) -> None: ...

    Command: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase
    )  # readonly
    Exception: System.Exception  # readonly

class CommandException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class CompoundPropertiesChangedEventArgs(System.EventArgs):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        properties: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
        ],
    ) -> None: ...

    Properties: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
    ]  # readonly

class CompoundProperty(System.MarshalByRefObject):  # Class
    def __init__(self, compoundId: int, name: str, value_: Any) -> None: ...

    CompoundId: int  # readonly
    Name: str  # readonly
    OldValue: Any  # readonly
    Value: Any

class ConversionSuggestedEventArgs(System.EventArgs):  # Class
    def __init__(self, type: SuggestedConversionType) -> None: ...

    ConversionType: SuggestedConversionType  # readonly

class ConversionType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    RI: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.ConversionType = (
        ...
    )  # static # readonly
    RTL: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.ConversionType = (
        ...
    )  # static # readonly
    RTLandRI: (
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.ConversionType
    ) = ...  # static # readonly

class ConvertLibrary(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        infoType: Agilent.MassSpectrometry.DataAnalysis.LibraryRTInfoType,
        destination: str,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class CreateLibrary(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
    ) -> None: ...

    IsDirtyCommand: bool  # readonly
    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class Delete(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compounds: List[CompoundKey],
        compoundProperties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
        ],
        spectra: List[SpectrumKey],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compounds: List[CompoundKey],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compoundProperties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
        ],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        spectra: List[SpectrumKey],
    ) -> None: ...

    Reversible: bool  # readonly

    def DeleteSpectrum(self, key: SpectrumKey) -> None: ...
    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def DeleteCompound(self, key: CompoundKey) -> None: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def DeleteCompoundProperty(self, key: CompoundKey, property: str) -> None: ...

class FilterSpectrumPeaks(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        spectrumKeys: List[SpectrumKey],
        relativeHeight: Optional[float],
        largestPeaks: Optional[int],
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class ImportJCAMP(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        files: List[str],
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class LibraryPropertiesChangedEventArgs(System.EventArgs):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        properties: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.LibraryProperty
        ],
    ) -> None: ...

    Properties: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.LibraryProperty
    ]  # readonly

class LibraryProperty:  # Class
    def __init__(self, name: str, value_: Any) -> None: ...

    Name: str  # readonly
    OldValue: Any  # readonly
    Value: Any

class NewCompound(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
        ],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

    CompoundId: int  # readonly
    Reversible: bool  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, name: str, value_: Any) -> None: ...

class NewSpectrum(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compoundId: int,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumProperty
        ],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compoundId: int,
    ) -> None: ...

    Reversible: bool  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(self, name: str, value_: Any) -> None: ...

class OpenLibrary(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        readOnly: bool,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        revisionNumber: str,
        readOnly: bool,
    ) -> None: ...

    IsDirtyCommand: bool  # readonly
    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class Paste(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compoundProperties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
        ],
        newCompounds: List[CompoundKey],
        spectrumProperties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumProperty
        ],
        newSpectra: List[SpectrumKey],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

    Reversible: bool  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def SetSpectrumProperties(
        self,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumProperty
        ],
    ) -> None: ...
    def NewSpectrum(
        self,
        compoundId: int,
        spectrumId: int,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumProperty
        ],
    ) -> None: ...
    def SetCompoundProperty(self, compoundId: int, name: str, value_: Any) -> None: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def NewCompound(
        self,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
        ],
    ) -> int: ...

class RedoCommand(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SaveLibrary(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

    IsDirtyCommand: bool  # readonly
    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SaveLibraryAs(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
        conversion: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.ConversionType,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        path: str,
        format: Agilent.MassSpectrometry.DataAnalysis.MSLibraryFormat,
    ) -> None: ...

    IsDirtyCommand: bool  # readonly
    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SetCompoundProperty(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CompoundProperty
        ],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compoundId: int,
        name: str,
        value_: Any,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SetLibraryProperty(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.LibraryProperty
        ],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def Redo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class SetSpectrumProperty(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        properties: List[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumProperty
        ],
    ) -> None: ...
    @overload
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compoundId: int,
        spectrumId: int,
        name: str,
        value_: Any,
    ) -> None: ...

    Reversible: bool  # readonly

    def Redo(self) -> Any: ...
    def Undo(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Do(self) -> Any: ...
    def SetProperty(
        self, compoundId: int, spectrumId: int, name: str, value_: Any
    ) -> None: ...

class SpectrumPropertiesChangedEventArgs(System.EventArgs):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        properties: Iterable[
            Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumProperty
        ],
    ) -> None: ...

    Properties: Iterable[
        Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.SpectrumProperty
    ]  # readonly

class SpectrumProperty(System.MarshalByRefObject):  # Class
    def __init__(
        self, compoundId: int, spectrumId: int, name: str, value_: Any
    ) -> None: ...

    CompoundId: int  # readonly
    Name: str  # readonly
    OldValue: Any  # readonly
    SpectrumId: int  # readonly
    Value: Any

class SynthesizeSpectra(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
        compounds: List[CompoundKey],
        replace: bool,
        species: List[str],
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...

class UndoCommand(
    Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.CommandBase,
    System.IDisposable,
    Agilent.MassSpectrometry.CommandModel.Model.ICommand,
):  # Class
    def __init__(
        self,
        context: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit.Commands.AppContext,
    ) -> None: ...

    Reversible: bool  # readonly
    Type: Agilent.MassSpectrometry.CommandModel.Model.CommandType  # readonly

    def Do(self) -> Any: ...
    def GetParameters(self) -> List[Any]: ...
    def Undo(self) -> Any: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import DoubleRange, IntRange, PlotTitles, Transition

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes

class ChromDataBuffer(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromSpecData,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromDataBuffer,
):  # Class
    @overload
    def __init__(
        self,
        firstCycleNumber: int,
        rt: System.Collections.Generic.List[float],
        cycleNumberRange: IntRange,
    ) -> None: ...
    @overload
    def __init__(
        self, xArray: List[float], yArray: List[float], cycleNumberRange: IntRange
    ) -> None: ...
    @overload
    def __init__(self, xArray: List[float], yArray: List[float]) -> None: ...

    Count: int  # readonly
    HasData: bool  # readonly
    HasGaps: bool  # readonly
    LastCycleNumber: int  # readonly
    NScanLinesForSpectrum: int  # readonly
    XArray: List[float]  # readonly
    YArray: List[float]  # readonly

    def Sort(self) -> None: ...
    @overload
    def AddChromDataSegment(
        self,
        abundances: System.Collections.Generic.List[float],
        startIndex: int,
        endIndex: int,
        startingCycleNumber: int,
    ) -> None: ...
    @overload
    def AddChromDataSegment(
        self,
        abundances: System.Collections.Generic.List[float],
        cycleNumbers: System.Collections.Generic.List[int],
        startIndex: int,
        endIndex: int,
    ) -> None: ...
    @overload
    def AddChromDataSegment(
        self,
        abundances: List[float],
        cycleNumbers: List[int],
        startIndex: int,
        endIndex: int,
    ) -> None: ...
    def AddChromDataSegment_CheckMaxMz(
        self,
        abundances: List[float],
        mzValues: List[float],
        cycleNumbers: List[int],
        startIndex: int,
        endIndex: int,
        maxMz: float,
    ) -> None: ...
    def AddChromDataSegment_CheckMinMz(
        self,
        abundances: List[float],
        mzValues: List[float],
        cycleNumbers: List[int],
        startIndex: int,
        endIndex: int,
        minMz: float,
    ) -> None: ...
    def AddDataSegment(
        self,
        seg: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.ChromDataBuffer,
    ) -> None: ...
    def AddDataPoint(self, abundance: float, cycleNumber: int) -> None: ...
    def AddChromDataSegment_CheckMinMaxMz(
        self,
        abundances: List[float],
        mzValues: List[float],
        cycleNumbers: List[int],
        startIndex: int,
        endIndex: int,
        minMz: float,
        maxMz: float,
    ) -> None: ...

class ChromSpecData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromSpecData
):  # Class
    @overload
    def __init__(self, xArray: List[float], yArray: List[float]) -> None: ...
    @overload
    def __init__(
        self, xArray: List[float], yArray: List[float], hasGaps: bool
    ) -> None: ...
    @overload
    def __init__(
        self, xArray: List[float], yArray: List[float], scanCount: int
    ) -> None: ...
    @overload
    def __init__(
        self,
        xList: System.Collections.Generic.List[float],
        yList: System.Collections.Generic.List[float],
    ) -> None: ...
    @overload
    def __init__(
        self,
        xList: System.Collections.Generic.List[float],
        yList: System.Collections.Generic.List[float],
        scanCount: int,
    ) -> None: ...
    @overload
    def __init__(self, xyData: Dict[float, float]) -> None: ...
    @overload
    def __init__(self, xyData: Dict[float, float], scanCount: int) -> None: ...
    @overload
    def __init__(self) -> None: ...

    Count: int  # readonly
    HasData: bool  # readonly
    HasGaps: bool  # readonly
    NScanLinesForSpectrum: int  # readonly
    XArray: List[float]  # readonly
    YArray: List[float]  # readonly

    def Sort(self) -> None: ...
    def AddDataSegment(
        self,
        moreData: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.ChromSpecData,
    ) -> None: ...

class IChromDataBuffer(object):  # Interface
    def AddDataPoint(self, abundance: float, cycleNumber: int) -> None: ...
    def AddChromDataSegment(
        self,
        abundances: List[float],
        cycleNumbers: List[int],
        startIndex: int,
        endIndex: int,
    ) -> None: ...

class IChromSpecData(object):  # Interface
    Count: int  # readonly
    HasData: bool  # readonly
    HasGaps: bool  # readonly
    NScanLinesForSpectrum: int  # readonly
    XArray: List[float]  # readonly
    YArray: List[float]  # readonly

    def Sort(self) -> None: ...

class IQuantMSScanInfo(object):  # Interface
    AverageScanStep: float  # readonly
    Polarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity  # readonly
    ScanTypes: Agilent.MassSpectrometry.DataAnalysis.MSScanType  # readonly

    def GetPolarities(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.IonPolarity
    ]: ...
    def GetMZs(
        self,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        polarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity,
        selectedMZ: float,
    ) -> System.Collections.Generic.List[float]: ...
    def GetScanTypes(
        self,
    ) -> System.Collections.Generic.List[
        Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ]: ...
    def GetPolarity(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> Agilent.MassSpectrometry.DataAnalysis.IonPolarity: ...
    def GetMRMTransitions(
        self,
    ) -> Dict[float, System.Collections.Generic.List[Transition]]: ...
    def GetSelectedMZs(
        self, scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType
    ) -> System.Collections.Generic.List[float]: ...
    def GetTransitions(
        self,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        polarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity,
    ) -> Dict[float, System.Collections.Generic.List[Transition]]: ...

class QuantChromatogram(
    Agilent.MassSpectrometry.DataAnalysis.IFXArrayStore,
    Agilent.MassSpectrometry.DataAnalysis.IFXStore,
    Agilent.MassSpectrometry.DataAnalysis.IXYStore,
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantXYData,
    Agilent.MassSpectrometry.DataAnalysis.IXYData,
    Agilent.MassSpectrometry.DataAnalysis.IFXData,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IUnitsConverter,
    Agilent.MassSpectrometry.DataAnalysis.IChromatogram,
    System.ICloneable,
):  # Class
    def __init__(
        self,
        chromData: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromSpecData,
        dataSourcePath: str,
        chromFilter: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractChrom,
    ) -> None: ...

    ChromFilter: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractChrom  # readonly

    @overload
    def InitTitle(
        self,
        titles: PlotTitles,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        polarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity,
        dataDirectory: str,
        smoothing: bool,
    ) -> None: ...
    @overload
    def InitTitle(
        self,
        titles: PlotTitles,
        deviceName: str,
        signalName: str,
        signalDescription: str,
        signalRange: DoubleRange,
        referenceRange: DoubleRange,
        dataDirectory: str,
        smoothing: bool,
    ) -> None: ...

class QuantDataSource(
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.IDataSource,
):  # Class
    def __init__(self) -> None: ...

class QuantDataUnits(
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.IDataUnits,
):  # Class
    QuantChromUnits: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantDataUnits
    )  # static

class QuantFileInfo(
    System.ICloneable, Agilent.MassSpectrometry.DataAnalysis.IBDAFileInformation
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        dataFileName: str,
        scanFileInfo: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantMSScanFileInfo,
        separationType: Agilent.MassSpectrometry.DataAnalysis.SeparationTechnique,
        msDataPresent: bool,
        nonMsDataPresent: bool,
    ) -> None: ...

class QuantMSChromatogram(
    Agilent.MassSpectrometry.DataAnalysis.IXYStore,
    Agilent.MassSpectrometry.DataAnalysis.IChromatogram,
    Agilent.MassSpectrometry.DataAnalysis.IFXData,
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantChromatogram,
    Agilent.MassSpectrometry.DataAnalysis.IXYData,
    Agilent.MassSpectrometry.DataAnalysis.ISpectralChromatogram,
    Agilent.MassSpectrometry.DataAnalysis.IFXStore,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
    Agilent.MassSpectrometry.DataAnalysis.IFXArrayStore,
    Agilent.MassSpectrometry.DataAnalysis.IMSChromatogram,
    Agilent.MassSpectrometry.DataAnalysis.IUnitsConverter,
):  # Class
    def __init__(
        self,
        chromData: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromSpecData,
        timeSegments: Agilent.MassSpectrometry.DataAnalysis.RangeCollection,
        dataSourcePath: str,
        chromFilter: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractChrom,
    ) -> None: ...

class QuantMSScanFileInfo(
    Agilent.MassSpectrometry.DataAnalysis.IBDAMSScanFileInformation,
    Iterable[Any],
    System.ICloneable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        polarity: Agilent.MassSpectrometry.DataAnalysis.IonPolarity,
        scanTypeInfo: System.Collections.Generic.List[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantMSScanTypeInfo
        ],
    ) -> None: ...

class QuantMSScanTypeInfo(
    Agilent.MassSpectrometry.DataAnalysis.IBDAMSScanTypeInformation, System.ICloneable
):  # Class
    def __init__(
        self,
        scanType: Agilent.MassSpectrometry.DataAnalysis.MSScanType,
        scanInfo: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IQuantMSScanInfo,
    ) -> None: ...

    QuantScanInfo: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IQuantMSScanInfo
    )  # readonly

    def Clone(self) -> Any: ...

class QuantMassSpectrum(
    Agilent.MassSpectrometry.DataAnalysis.IFXData,
    Agilent.MassSpectrometry.DataAnalysis.IXYStore,
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.ISpectrum,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantSpectrum,
    Agilent.MassSpectrometry.DataAnalysis.IUnitsConverter,
    Agilent.MassSpectrometry.DataAnalysis.IFXStore,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IXYData,
    Agilent.MassSpectrometry.DataAnalysis.IMassSpectrum,
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
    Agilent.MassSpectrometry.DataAnalysis.IFXArrayStore,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        specData: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromSpecData,
        filter: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractSpectrum,
        dataSourcePath: str,
        isProfileData: bool,
    ) -> None: ...

    ContributingRtRanges: System.Collections.Generic.List[DoubleRange]  # readonly

    @overload
    def InitTitle(self, titles: PlotTitles, dataDirectory: str) -> None: ...
    @overload
    def InitTitle(
        self, titles: PlotTitles, dataDirectory: str, scanStep: float
    ) -> None: ...

class QuantNoiseResult(
    Agilent.MassSpectrometry.DataAnalysis.IResult,
    Agilent.MassSpectrometry.DataAnalysis.INoiseResult,
    System.ICloneable,
):  # Class
    def __init__(self) -> None: ...

    NoiseMultiplier: float
    NoiseRegions: Agilent.MassSpectrometry.DataAnalysis.RangeCollection
    NoiseType: Agilent.MassSpectrometry.DataAnalysis.NoiseType
    NoiseValue: float
    SignalType: Agilent.MassSpectrometry.DataAnalysis.ResultAttribute

    def ClearCompoundResultAttributes(
        self, cpd: Agilent.MassSpectrometry.DataAnalysis.ICompound
    ) -> None: ...
    def ContainIDResult(self) -> bool: ...
    def WriteXML(self, writer: System.Xml.XmlWriter) -> None: ...
    def SynchronizeCompoundResultAttributes(
        self, cpd: Agilent.MassSpectrometry.DataAnalysis.ICompound
    ) -> None: ...

class QuantPSet(
    Iterable[Any],
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.ICollectionElement,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IParameter,
    Agilent.MassSpectrometry.DataAnalysis.IParameterSet,
):  # Class
    ...

class QuantPSetChromPeakFilter(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantPSet,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IPSetPeakFilter,
    Agilent.MassSpectrometry.DataAnalysis.IParameterSet,
    Agilent.MassSpectrometry.DataAnalysis.ICollectionElement,
    Agilent.MassSpectrometry.DataAnalysis.IParameter,
    System.ICloneable,
    Iterable[Any],
):  # Class
    def __init__(self) -> None: ...

class QuantPSetExtractChrom(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantPSet,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IParameterSet,
    Agilent.MassSpectrometry.DataAnalysis.ICollectionElement,
    Agilent.MassSpectrometry.DataAnalysis.IParameter,
    Agilent.MassSpectrometry.DataAnalysis.IPSetExtractChrom,
    System.ICloneable,
    Iterable[Any],
):  # Class
    def __init__(self) -> None: ...

    CompoundName: str
    IntegratorName: str
    NeedTitle: bool
    NoiseMultiplier: float
    NoiseType: str
    Smoothing: bool
    UseEicIfEmptyFeatureChrom: bool

class QuantPSetExtractSpectrum(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantPSet,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IParameterSet,
    Agilent.MassSpectrometry.DataAnalysis.ICollectionElement,
    Agilent.MassSpectrometry.DataAnalysis.IParameter,
    System.ICloneable,
    Iterable[Any],
    Agilent.MassSpectrometry.DataAnalysis.IPSetExtractSpectrum,
):  # Class
    def __init__(self) -> None: ...

    CompoundName: str
    DeviceName: str
    MzRanges: System.Collections.Generic.List[DoubleRange]
    NeedTitle: bool
    NoiseThreshold: float
    ReferenceWavelength: Agilent.MassSpectrometry.DataAnalysis.IRange
    SaturationThreshold: float
    SaturationTrackingMzRanges: System.Collections.Generic.List[DoubleRange]
    SignalName: str
    SignalWavelength: Agilent.MassSpectrometry.DataAnalysis.IRange
    UseReference: bool

class QuantPSetSignalToNoise(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantPSet,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IParameterSet,
    Agilent.MassSpectrometry.DataAnalysis.ICollectionElement,
    Agilent.MassSpectrometry.DataAnalysis.IParameter,
    System.ICloneable,
    Iterable[Any],
    Agilent.MassSpectrometry.DataAnalysis.IPSetSignalToNoise,
):  # Class
    def __init__(self) -> None: ...

class QuantPlotPreferences:  # Class
    def __init__(self) -> None: ...

    DrawingMode: Agilent.MassSpectrometry.DataAnalysis.DrawingMode
    XAxisLabel: str
    YAxisLabel: str

class QuantSpectrum(
    Agilent.MassSpectrometry.DataAnalysis.IFXArrayStore,
    Agilent.MassSpectrometry.DataAnalysis.IFXStore,
    Agilent.MassSpectrometry.DataAnalysis.IXYStore,
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.QuantXYData,
    Agilent.MassSpectrometry.DataAnalysis.IXYData,
    Agilent.MassSpectrometry.DataAnalysis.IFXData,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IUnitsConverter,
    Agilent.MassSpectrometry.DataAnalysis.ISpectrum,
    System.ICloneable,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(
        self,
        specData: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromSpecData,
        filter: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractSpectrum,
        dataSourcePath: str,
    ) -> None: ...

    SpecFilter: Agilent.MassSpectrometry.DataAnalysis.IPSetExtractSpectrum  # readonly

    def InitTitle(
        self, titles: PlotTitles, dataDirectory: str, scanStep: float
    ) -> None: ...

class QuantXYData(
    Agilent.MassSpectrometry.DataAnalysis.IXYStore,
    Agilent.MassSpectrometry.DataAnalysis.IUnitsConverter,
    Agilent.MassSpectrometry.DataAnalysis.IFXData,
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.IFXStore,
    Agilent.MassSpectrometry.DataAnalysis.IFXArrayStore,
    Agilent.MassSpectrometry.DataAnalysis.IXYData,
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, xArray: List[float], yArray: List[float]) -> None: ...

    Count: int  # readonly
    HasGaps: bool  # readonly

    def GetYArray(self, copy: bool) -> List[float]: ...
    def GetXArray(self, copy: bool) -> List[float]: ...

class QuantXYDataDescription(
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.IDescription,
    Agilent.MassSpectrometry.DataAnalysis.IConvertibleValueContainer,
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
):  # Class
    def __init__(self) -> None: ...

class QuantXYLimits(
    System.ICloneable,
    Agilent.MassSpectrometry.DataAnalysis.IFXLimits,
    Agilent.MassSpectrometry.DataAnalysis.IXYLimits,
    Agilent.MassSpectrometry.DataAnalysis.IConsistency,
):  # Class
    ...

class SparseChromDataBuffer(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromDataBuffer
):  # Class
    def __init__(
        self,
        cycleNumbers: System.Collections.Generic.List[int],
        rtValues: System.Collections.Generic.List[float],
    ) -> None: ...

    XValues: List[float]  # readonly
    YValues: List[float]  # readonly

    def AddDataPoint(self, abundance: float, cycleNumber: int) -> None: ...
    def AddChromDataSegment(
        self,
        abundances: List[float],
        cycleNumbers: List[int],
        minIndex: int,
        maxIndex: int,
    ) -> None: ...

class TofSpecData(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CoreDataTypes.IChromSpecData
):  # Class
    def __init__(
        self,
        mzValues: List[float],
        abundances: List[float],
        rtRanges: System.Collections.Generic.List[DoubleRange],
        scanCount: int,
    ) -> None: ...

    Count: int  # readonly
    HasData: bool  # readonly
    HasGaps: bool  # readonly
    NScanLinesForSpectrum: int  # readonly
    RtRanges: System.Collections.Generic.List[DoubleRange]  # readonly
    XArray: List[float]  # readonly
    YArray: List[float]  # readonly

    def Sort(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Tools import ITool, ITools, IToolString

# Stubs for namespace: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model

class AvailableToolCategory(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.IAvailableToolCategory
):  # Class
    def __init__(
        self,
        id: str,
        displayName: str,
        tools: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase],
        toolString: IToolString,
    ) -> None: ...

    DisplayName: str  # readonly
    Name: str  # readonly
    Tools: List[ITool]  # readonly

class CustomizeRibbonModel(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeRibbonModel
):  # Class
    def __init__(self) -> None: ...

    CustomizeWindowTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeWindowTarget
    ]  # readonly

    def Save(self, rootFolder: str) -> None: ...
    def ResetToDefault(self) -> None: ...
    def Initialize(self, rootFolder: str) -> None: ...
    def IsDirty(self) -> bool: ...
    @staticmethod
    def CreateTool(
        parent: ITools,
        tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase,
        toolString: IToolString,
    ) -> ITool: ...
    @staticmethod
    def CreateTools(
        parent: ITools,
        tools: List[Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase],
        toolString: IToolString,
    ) -> List[ITool]: ...

class CustomizeRibbonTarget(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeRibbonTarget,
    ITools,
):  # Class
    def __init__(self, name: str, toolString: IToolString) -> None: ...

    Children: List[ITool]  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly
    RootTools: ITools  # readonly
    TargetType: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.RibbonTargetType
    )  # readonly

    def MoveDown(self, child: ITool) -> None: ...
    def InitializeRibbon(
        self, ribbon: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Ribbon
    ) -> None: ...
    def MoveUp(self, child: ITool) -> None: ...
    def CanMoveDown(self, tool: ITool) -> bool: ...
    def CanInsert(self, child: ITool) -> bool: ...
    def Remove(self, child: ITool) -> None: ...
    def Commit(self) -> List[Any]: ...
    def Insert(self, child: ITool, after: ITool) -> None: ...
    def CanMoveUp(self, tool: ITool) -> bool: ...

class CustomizeWindowTarget(
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeWindowTarget,
    IToolString,
):  # Class
    def __init__(self, fileName: str, name: str, displayName: str) -> None: ...

    AvailableToolCategories: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.IAvailableToolCategory
    ]  # readonly
    CustomizeRibbonTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeRibbonTarget
    ]  # readonly
    DisplayName: str  # readonly
    FileName: str  # readonly
    Name: str  # readonly
    ToolString: IToolString  # readonly

    def ResetToDefault(self) -> None: ...
    def Initialize(
        self,
        tools: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools,
        defaultTools: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools,
        rmgrWpf: System.Resources.ResourceManager,
        rmgrLegacy: System.Resources.ResourceManager,
    ) -> None: ...
    @overload
    def GetToolbarCaption(
        self, toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolbarDef
    ) -> str: ...
    @overload
    def GetToolbarCaption(self, id: str) -> str: ...
    def GetCategoryDisplayName(self, cat: str) -> str: ...
    def IsDirty(self) -> bool: ...
    @overload
    def GetToolTooltip(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
    ) -> str: ...
    @overload
    def GetToolTooltip(self, id: str) -> str: ...
    def CommitTo(
        self, tools: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.Tools
    ) -> None: ...
    def GetContextMenuDisplayName(self, id: str) -> str: ...
    def FindDefaultTool(
        self, id: str
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...
    def GetString(self, id: str, prefix: str, suffix: str) -> str: ...
    @overload
    def GetToolCaption(
        self, tool: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase
    ) -> str: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...
    def Save(self, rootFolder: str) -> None: ...

class IAvailableToolCategory(object):  # Interface
    DisplayName: str  # readonly
    Name: str  # readonly
    Tools: List[ITool]  # readonly

class ICustomizeRibbonModel(object):  # Interface
    CustomizeWindowTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeWindowTarget
    ]  # readonly

    def ResetToDefault(self) -> None: ...
    def IsDirty(self) -> bool: ...
    def Save(self, rootFolder: str) -> None: ...

class ICustomizeRibbonTarget(object):  # Interface
    DisplayName: str  # readonly
    Name: str  # readonly
    RootTools: ITools  # readonly
    TargetType: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.RibbonTargetType
    )  # readonly

    def Commit(self) -> List[Any]: ...

class ICustomizeWindowTarget(object):  # Interface
    AvailableToolCategories: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.IAvailableToolCategory
    ]  # readonly
    CustomizeRibbonTargets: List[
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeRibbonTarget
    ]  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly
    ToolString: IToolString  # readonly

    def FindDefaultTool(
        self, id: str
    ) -> Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolBase: ...
    def IsDirty(self) -> bool: ...
    def ResetToDefault(self) -> None: ...
    def Save(self, rootFolder: str) -> None: ...

class PaneTarget(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIUtils2.NotifyPropertyBase,
    System.ComponentModel.INotifyPropertyChanged,
    Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.ICustomizeRibbonTarget,
    ITools,
):  # Class
    def __init__(self, name: str, toolString: IToolString) -> None: ...

    AvailableTools: List[ITool]  # readonly
    Children: List[ITool]  # readonly
    DisplayName: str  # readonly
    Name: str  # readonly
    RootTools: ITools  # readonly
    TargetType: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.RibbonTargetType
    )  # readonly

    def MoveDown(self, child: ITool) -> None: ...
    def AddToolbar(
        self, toolbar: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ToolbarDef
    ) -> None: ...
    def MoveUp(self, child: ITool) -> None: ...
    def CanMoveDown(self, child: ITool) -> bool: ...
    def CanInsert(self, child: ITool) -> bool: ...
    def Remove(self, child: ITool) -> None: ...
    def Commit(self) -> List[Any]: ...
    def Insert(self, child: ITool, after: ITool) -> None: ...
    def CanMoveUp(self, child: ITool) -> bool: ...
    def AddContextMenu(
        self,
        contextMenu: Agilent.MassHunter.Quantitative.ToolbarWPF.Definitions.ContextMenu,
    ) -> None: ...

class RibbonTargetType(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    Pane: Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.RibbonTargetType = (
        ...
    )  # static # readonly
    Ribbon: (
        Agilent.MassHunter.Quantitative.Startup.Edit.Ribbon.Model.RibbonTargetType
    ) = ...  # static # readonly



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import AppMenu, Tools

# Discovered Generic TypeVars:
T = TypeVar("T")
from .QuantAppServices import Service
from .ToolbarWPF.Definitions import ExplorerBar
from .ToolbarWPF.ToolManager import IToolManager, ToolManagerBase
from .ToolbarWPF.ToolState import IToolState
from .UIModel import (
    ICagWindow,
    ICalCurvePane,
    IChromatogramInformationGridView,
    IChromatogramInformationUIContext,
    IChromatogramInformationView,
    IChromatogramInformationWindow,
    IChromSpecPane,
    IChromSpecProperties,
    ICustomPane,
    IDataNavigator,
    IDockManager,
    IDockPane,
    IMainWindow,
    IMethodErrorListPane,
    IMethodTablePane,
    IMethodTasksPane,
    IMetricsPlotPane,
    IPresentationState,
    ISampleDataPane,
    IScriptPane,
    IStatusBar,
    IWorktablePane,
)

# Stubs for namespace: Agilent.MassHunter.Quantitative.QuantWPF

class App(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.IAppContext,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
    System.Windows.Application,
):  # Class
    def __init__(self) -> None: ...

    PresentationState: IPresentationState  # readonly
    ScriptTesting: bool
    UIState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState
    )  # readonly

    @staticmethod
    def RegisterApplicationService(
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
        mainWindow: Agilent.MassHunter.Quantitative.QuantWPF.MainWindow,
        key: str,
    ) -> Service: ...
    def ShowErrorMessage(self, exception: System.Exception) -> None: ...
    def ExitThread(self) -> None: ...
    @staticmethod
    def Main() -> None: ...
    def InitializeComponent(self) -> None: ...

    Initialized: System.EventHandler  # Event

class CagAddInManager(
    System.MarshalByRefObject,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAddInManager,
):  # Class
    def __getitem__(
        self, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IAddIn: ...
    def Initialize(self) -> None: ...
    def Clear(self) -> None: ...
    def Dispose(self) -> None: ...
    def GetIDs(self) -> List[str]: ...

class CagWindow(
    System.Windows.Markup.IAddChild,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.Markup.IHaveResources,
    System.Windows.IInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.IWindowService,
    ICagWindow,
    System.Windows.Forms.IWin32Window,
):  # Class
    def __init__(self) -> None: ...

    ContainsFocus: bool  # readonly
    DataNavigator: IDataNavigator  # readonly
    Handle: System.IntPtr  # readonly
    Height: int
    InvokeRequired: bool  # readonly
    IsHandleCreated: bool  # readonly
    Location: System.Drawing.Point
    PresentationState: IPresentationState  # readonly
    ToolbarsManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager
    )  # readonly
    Visible: bool  # readonly
    Width: int
    WindowState: System.Windows.Forms.FormWindowState

    def ShowHelpContents(self) -> None: ...
    def GetAddInManager(self) -> T: ...
    def Initialize(
        self,
        navigator: IDataNavigator,
        uiState: Agilent.MassHunter.Quantitative.QuantWPF.UIState,
        props: IChromSpecProperties,
    ) -> None: ...
    def ShowSetupGraphicsDialog(self) -> None: ...
    def ShowHelpIndex(self) -> None: ...
    def GetSelectedCompounds(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.TargetCompoundRowId
    ]: ...
    def GetSelectedSamples(
        self,
    ) -> List[Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleRowId]: ...
    def GetChromatogramControl(self) -> T: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def Update(self) -> None: ...
    def SetCurrentLayoutAsDefault(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def GetSetupGraphicsContext(self) -> T: ...
    def GetToolbar(
        self, pane: str, id: str
    ) -> Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbar: ...
    def ShowHelpSearch(self) -> None: ...
    def Invoke(self, del_: System.Delegate, parameters: List[Any]) -> Any: ...
    def LoadDefaultLayout(self, loadAllSamplesCompounds: bool) -> bool: ...

    Disposed: System.EventHandler  # Event

class ChromatogramInformationWindow(
    System.Windows.Markup.IAddChild,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.Markup.IHaveResources,
    System.Windows.IInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.IWindowService,
    System.Windows.Forms.IWin32Window,
    IChromatogramInformationWindow,
):  # Class
    def __init__(self) -> None: ...

    ChromView: IChromatogramInformationView  # readonly
    ContainsFocus: bool  # readonly
    GridView: IChromatogramInformationGridView  # readonly
    Handle: System.IntPtr  # readonly
    HeadToTail: bool
    Height: int
    InvokeRequired: bool  # readonly
    IsHandleCreated: bool  # readonly
    LinkXAxes: bool
    LinkYAxes: bool
    Location: System.Drawing.Point
    MaxNumVisibleRows: int
    Overlay: bool
    ToolbarsManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager
    )  # readonly
    UIContext: IChromatogramInformationUIContext  # readonly
    Visible: bool  # readonly
    Width: int
    WindowState: System.Windows.Forms.FormWindowState

    def Initialize(
        self,
        dataNavigator: IDataNavigator,
        uiState: Agilent.MassHunter.Quantitative.QuantWPF.UIState,
    ) -> None: ...
    def AutoScaleY(self) -> None: ...
    def CanAutoScale(self) -> bool: ...
    def Copy(self) -> None: ...
    def AutoScaleX(self) -> None: ...
    def CanCopy(self) -> bool: ...
    def InitializeComponent(self) -> None: ...
    def CreatePropertyPages(
        self,
    ) -> List[
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Controls2.IPropertyPage
    ]: ...
    def AutoScaleXY(self) -> None: ...
    def CanCreateCompound(self) -> bool: ...
    def CreateCompound(self) -> None: ...
    @overload
    def Invoke(self, d: System.Delegate, parameters: List[Any]) -> Any: ...
    @overload
    def Invoke(self, d: System.Delegate) -> Any: ...

    Disposed: System.EventHandler  # Event

class CommandLine(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CommandLine
):  # Class
    def __init__(self) -> None: ...

    StartupPath: str

class DockManager(System.IDisposable, IDockManager):  # Class
    def __init__(
        self, mainWindow: Agilent.MassHunter.Quantitative.QuantWPF.MainWindow
    ) -> None: ...

    ActivePane: IDockPane  # readonly

    def ControlPaneExists(self, paneId: str) -> bool: ...
    def Dispose(self) -> None: ...
    def GetPane(self, paneId: str) -> IDockPane: ...

class DockPane(IDockPane):  # Class
    def __init__(
        self, host: System.Windows.Forms.Integration.WindowsFormsHost
    ) -> None: ...

    Control: System.Windows.Forms.Control  # readonly

class MainWindow(
    System.Windows.Markup.IAddChild,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.Markup.IHaveResources,
    System.Windows.IInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.IFrameworkInputElement,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IQueryAmbient,
    IMainWindow,
    System.Windows.IWindowService,
    System.Windows.Forms.IWin32Window,
):  # Class
    def __init__(
        self,
        presentationState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.PresentationState,
        appService: bool,
    ) -> None: ...

    CalCurvePane: ICalCurvePane  # readonly
    ChromSpecPane: IChromSpecPane  # readonly
    CommandContext: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.AppCommandContext
    )  # readonly
    ContainsFocus: bool  # readonly
    DataNavigator: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.DataNavigator
    )  # readonly
    DockManager: IDockManager  # readonly
    Handle: System.IntPtr  # readonly
    Height: int
    InvokeRequired: bool  # readonly
    IsDisposed: bool  # readonly
    IsHandleCreated: bool  # readonly
    Location: System.Drawing.Point
    MethodErrorListPane: IMethodErrorListPane  # readonly
    MethodTablePane: IMethodTablePane  # readonly
    MethodTasksPane: IMethodTasksPane  # readonly
    MetricsPlotPane: IMetricsPlotPane  # readonly
    PresentationState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.PresentationState
    )  # readonly
    SampleDataPane: ISampleDataPane  # readonly
    ScriptPane: IScriptPane  # readonly
    StatusBar: IStatusBar  # readonly
    Text: str
    ToolbarsManager: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager
    )  # readonly
    UIState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState
    )  # readonly
    Width: int
    WorktablePane: IWorktablePane  # readonly
    _CalCurvePane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CalCurve
    )  # readonly
    _ChromSpec: Agilent.MassSpectrometry.DataAnalysis.Quantitative.ChromSpec  # readonly
    _DockManager: Infragistics.Windows.DockManager.XamDockManager  # readonly
    _Ribbon: Infragistics.Windows.Ribbon.XamRibbon  # readonly
    _SampleDataPane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.SampleData.SampleDataControl
    )  # readonly
    _Worktable: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Worktable  # readonly

    def CustomPaneExists(self, key: str) -> bool: ...
    def ShowAboutBox(self) -> None: ...
    def SaveLayout(self, stream: System.IO.Stream) -> None: ...
    def Invoke(self, d: System.Delegate) -> Any: ...
    def RegisterCustomPane(
        self, register: bool, key: str, pane: ICustomPane
    ) -> None: ...
    def IsPaneVisible(self, name: str) -> bool: ...
    def InitializeComponent(self) -> None: ...
    def ResetLayout(self) -> None: ...
    def ShowMethodErrorListPane(self) -> None: ...
    def ForceClose(self) -> None: ...
    def ValidateMethod(self, alwaysShowPane: bool) -> None: ...
    def GetCustomPane(self, key: str) -> ICustomPane: ...
    def Activate(self) -> None: ...
    def SetPaneVisible(self, name: str, visible: bool) -> None: ...
    def LoadLayout(self, stream: System.IO.Stream) -> None: ...
    def MaximizePane(self, paneKey: str) -> None: ...
    def ActivatePane(self, name: str) -> None: ...
    @staticmethod
    def IsModal(window: System.Windows.Window) -> bool: ...
    def LayoutPanes(self, pattern: int) -> None: ...
    def IsInModalState(self) -> bool: ...
    def ShowWindow(self) -> None: ...

class MethodTasksControl(
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Markup.IHaveResources,
    IMethodTasksPane,
    System.Windows.Markup.IAddChild,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
):  # Class
    def __init__(self) -> None: ...

    Panel: System.Windows.Controls.StackPanel  # readonly

    def InitializeComponent(self) -> None: ...
    def InitTools(
        self,
        definitions: ExplorerBar,
        toolManager: Agilent.MassHunter.Quantitative.QuantWPF.ToolManager,
        rmgr: System.Resources.ResourceManager,
    ) -> None: ...
    def GetGroup(
        self, id: str
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IExplorerBarGroup
    ): ...

class StatusBar(IStatusBar):  # Class
    def __init__(
        self, mainWindow: Agilent.MassHunter.Quantitative.QuantWPF.MainWindow
    ) -> None: ...

    Visible: bool

class StatusBarController(System.IDisposable):  # Class
    def __init__(
        self, window: Agilent.MassHunter.Quantitative.QuantWPF.MainWindow
    ) -> None: ...
    def Dispose(self) -> None: ...

class ToolHandlerApplicationMenu(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolHandler
):  # Class
    def __init__(self) -> None: ...
    def Execute(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiStateObj: Any,
    ) -> None: ...
    def SetState(
        self,
        toolState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolState,
        uiStateObj: Any,
    ) -> None: ...

class ToolIds:  # Class
    def __init__(self) -> None: ...

    App_File_About: str = ...  # static # readonly
    App_File_NewBatch: str = ...  # static # readonly
    App_File_OpenBatch: str = ...  # static # readonly
    App_File_SaveAs: str = ...  # static # readonly
    ContextualTabGroup_ManualIntegrate: str = ...  # static # readonly
    View_BatchTableLayout: str = ...  # static # readonly
    View_ExpandCollapse: str = ...  # static # readonly
    View_Layout_LoadSaveLayout: str = ...  # static # readonly
    View_Layout_MaximizePane: str = ...  # static # readonly
    View_Layout_PresetLayouts: str = ...  # static # readonly
    View_Panes: str = ...  # static # readonly

class ToolManager(
    ToolManagerBase,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar2.IToolManager,
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.Toolbar.IToolbarsManager,
    IToolManager,
):  # Class
    def __init__(
        self,
        ribbon: Infragistics.Windows.Ribbon.XamRibbon,
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> None: ...

    IUIState: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState
    )  # readonly

    @staticmethod
    def GetImageNames() -> List[str]: ...
    def RegisterScriptToolHandler(
        self, id: str, module: str, setState: str, execute: str
    ) -> None: ...
    def ApplicationMenu2010SelectedTabItemChanged(self) -> None: ...
    def SetToolState(self, state: IToolState) -> None: ...
    def GetImage(self, image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def GetToolbarTitle(self, id: str) -> str: ...
    def GetApplicationMenu2010Content(self, category: str, id: str) -> Any: ...
    def GetToolTooltip(self, id: str) -> str: ...
    def IsContextualTabGroupVisible(self, id: str) -> bool: ...
    @staticmethod
    def _GetImage(image: str) -> System.Windows.Media.Imaging.BitmapSource: ...
    def ApplicationMenu2010Closed(self) -> None: ...
    def RegisterScriptCategoryHandler(
        self, category: str, module: str, setState: str, execute: str
    ) -> None: ...
    @overload
    def GetToolCaption(
        self, id: str, culture: System.Globalization.CultureInfo
    ) -> str: ...
    @overload
    def GetToolCaption(self, id: str) -> str: ...

class UIState(
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIFImpls.UIState,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
):  # Class
    def __init__(
        self, win: Agilent.MassHunter.Quantitative.QuantWPF.MainWindow
    ) -> None: ...

    ActivePane: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IPane
    )  # readonly

    def CreateCagWindow(self) -> ICagWindow: ...
    def CreateChromatogramInformationWindow(self) -> IChromatogramInformationWindow: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

# Stubs for namespace: Agilent.MassHunter.Quantitative.ConvertSamples

class App(
    System.Windows.Application,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    @staticmethod
    def Main() -> None: ...

class CommandLine:  # Class
    def __init__(self) -> None: ...

    BatchFolder: str
    Culture: str

class ConvertSamplesContext(
    System.IConvertible, System.IComparable, System.IFormattable
):  # Struct
    CreateBatch: (
        Agilent.MassHunter.Quantitative.ConvertSamples.ConvertSamplesContext
    ) = ...  # static # readonly
    OpenBatchOrApplyMethod: (
        Agilent.MassHunter.Quantitative.ConvertSamples.ConvertSamplesContext
    ) = ...  # static # readonly

class ConvertTofDataControl(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.Media.Animation.IAnimatable,
    System.Windows.Controls.UserControl,
    System.Windows.IInputElement,
    System.Windows.Markup.IHaveResources,
    System.Windows.Markup.IComponentConnector,
    System.Windows.IFrameworkInputElement,
    System.ComponentModel.ISupportInitialize,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Markup.IAddChild,
):  # Class
    def __init__(self) -> None: ...
    def InitializeComponent(self) -> None: ...
    def SetBatchFolder(self, batchFolder: str) -> None: ...
    def SetSamples(self, batchFolder: str, samplePaths: List[str]) -> None: ...

class ConvertTofDataModel(System.ComponentModel.INotifyPropertyChanged):  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.ConvertSamples.Model
    ) -> None: ...

    AlwaysConvert: bool
    AlwaysConvertEnabled: bool  # readonly
    BatchFolder: str
    CanConvert: bool  # readonly
    CanDeleteFD: bool  # readonly
    CanDeleteTDA: bool  # readonly
    ConvertToFD: bool
    ConvertToTDA: bool
    DeleteFD: bool
    DeleteTDA: bool
    Model: Agilent.MassHunter.Quantitative.ConvertSamples.Model  # readonly
    Samples: List[
        Agilent.MassHunter.Quantitative.ConvertSamples.ConvertTofDataSample
    ]  # readonly

    def Clear(self) -> None: ...
    @overload
    def SetSamples(self, batchFolder: str, samplePaths: List[str]) -> None: ...
    @overload
    def SetSamples(self, batchFolder: str) -> None: ...
    def UpdateSamples(self) -> None: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class ConvertTofDataSample:  # Class
    def __init__(
        self, model: Agilent.MassHunter.Quantitative.ConvertSamples.ConvertTofDataModel
    ) -> None: ...

    AcqDateTime: Optional[System.DateTime]
    CanConvertToFD: bool
    CanConvertToTDA: bool
    DataFileName: str
    FeatureDetected: bool
    IsSelected: bool
    PathName: str
    SampleGroup: str
    SampleName: str
    TDAConverted: bool

class ConvertUtils:  # Class
    @staticmethod
    def GetSampleInfo(
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        samples: List[str],
    ) -> List[Agilent.MassHunter.Quantitative.ConvertSamples.ConvertTofDataSample]: ...
    @staticmethod
    def DoesBatchRequireFD(
        bds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.BatchDataSet,
        batchId: int,
    ) -> bool: ...
    @staticmethod
    def CheckTofData(
        samplePaths: List[str],
        hasTOFSamples: bool,
        hasSamplesWithoutFD: bool,
        hasSamplesWithoutTDA: bool,
    ) -> None: ...
    @overload
    @staticmethod
    def CheckSamplesAndShowConvertWindow(
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
    ) -> bool: ...
    @overload
    @staticmethod
    def CheckSamplesAndShowConvertWindow(
        uiState: Agilent.MassSpectrometry.DataAnalysis.Quantitative.UIScriptIF.IUIState,
        requireFD: bool,
        useProfile: bool,
    ) -> bool: ...
    @overload
    @staticmethod
    def CheckSamplesAndShowConvertWindow(
        parent: System.Windows.Forms.IWin32Window,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        batchFolder: str,
        samplePathNames: List[str],
        context: Agilent.MassHunter.Quantitative.ConvertSamples.ConvertSamplesContext,
        requireFD: bool,
        useProfile: bool,
    ) -> bool: ...
    @staticmethod
    def DoesBatchUseProfile(
        bds: Agilent.MassSpectrometry.DataAnalysis.Quantitative.BatchDataSet,
        batchId: int,
    ) -> bool: ...

class Converter:  # Class
    def __init__(self) -> None: ...
    def DetectFeatures(
        self,
        samplePath: str,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...
    def ConvertToTDA(
        self,
        samplePath: str,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...
    def Abort(self) -> None: ...

class MainWindow(
    System.Windows.Media.Composition.DUCE.IResource,
    System.Windows.IWindowService,
    Infragistics.Windows.Ribbon.IRibbonWindow,
    System.Windows.Markup.IQueryAmbient,
    System.Windows.Media.Animation.IAnimatable,
    System.ComponentModel.ISupportInitialize,
    Infragistics.Windows.Ribbon.XamRibbonWindow,
    System.Windows.IInputElement,
    System.Windows.IFrameworkInputElement,
    System.Windows.Markup.IAddChild,
    System.Windows.Markup.IComponentConnector,
    System.Windows.Markup.IHaveResources,
):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
    ) -> None: ...
    def InitializeComponent(self) -> None: ...
    def SetBatchFolder(self, batchFolder: str) -> None: ...
    def SetSamples(self, batchFolder: str, samplePaths: List[str]) -> None: ...
    def ShowDialogAndInitialize(
        self, batchPath: str, samplePaths: List[str]
    ) -> Optional[bool]: ...

class Model(System.ComponentModel.INotifyPropertyChanged):  # Class
    def __init__(
        self,
        compliance: Agilent.MassSpectrometry.DataAnalysis.Quantitative.Compliance.ICompliance,
        window: Agilent.MassHunter.Quantitative.ConvertSamples.MainWindow,
    ) -> None: ...

    CanAbort: bool  # readonly
    CanBack: bool  # readonly
    CanClose: bool  # readonly
    CanConvert: bool  # readonly
    ControllVisibility: System.Windows.Visibility  # readonly
    ConvertTofDataModel: (
        Agilent.MassHunter.Quantitative.ConvertSamples.ConvertTofDataModel
    )  # readonly
    ElapsedTime: str  # readonly
    Progress: float  # readonly
    ProgressText: str  # readonly
    ProgressVisibility: System.Windows.Visibility  # readonly

    def BeginConvert(self) -> System.IAsyncResult: ...
    def Abort(self) -> None: ...

    PropertyChanged: System.ComponentModel.PropertyChangedEventHandler  # Event

class RemoteConverter(System.MarshalByRefObject, System.IDisposable):  # Class
    def __init__(self) -> None: ...
    def InitializeLifetimeService(self) -> Any: ...
    def ConvertToTDA(self, samplePath: str) -> None: ...
    def DetectFeatures(self, samplePath: str) -> None: ...
    def Abort(self) -> None: ...
    def Dispose(self) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .UIUtils2 import ConfigurationElementSectionBase

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles

class AppConfig:  # Class
    ApplicationSettings: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.ApplicationSettings
    )  # readonly
    Instance: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.AppConfig
    )  # static # readonly
    UserSettings: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.UserSettings
    )  # readonly

    def Save(self) -> None: ...

class ApplicationSettings(ConfigurationElementSectionBase):  # Class
    def __init__(self) -> None: ...

    DumpLogOnNormalExit: bool  # readonly
    ErrorReportingEmailAddress: str  # readonly
    ErrorReportingEnabled: bool  # readonly

class BroncoMethodChecker(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.PicardFolderChecker,
):  # Class
    def __init__(
        self,
        folder: str,
        fileType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType,
        abort: System.Threading.WaitHandle,
    ) -> None: ...

class CheckResults:  # Class
    def __init__(
        self,
        file: str,
        fileType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType,
    ) -> None: ...

    AnalysisTimestamp: str = ...  # static # readonly
    AuditTrailValid: str = ...  # static # readonly
    DataVersion: str = ...  # static # readonly
    HashCodeValid: str = ...  # static # readonly
    LastWrittenTime: str = ...  # static # readonly

    Aborted: bool
    Complete: bool
    Exception: System.Exception
    File: str  # readonly
    FileType: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    )  # readonly

    def Equals(self, obj: Any) -> bool: ...
    def Contains(self, key: str) -> bool: ...
    def GetValue(self, key: str) -> Any: ...
    def GetError(self, key: str) -> str: ...
    def SetValue(self, key: str, value_: Any) -> None: ...
    def GetHashCode(self) -> int: ...
    def Clone(
        self,
    ) -> (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResults
    ): ...
    def SetError(self, key: str, error: str) -> None: ...
    def Apply(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...

class CheckResultsDataSet(
    System.IDisposable,
    System.ComponentModel.ISupportInitializeNotification,
    System.IServiceProvider,
    System.Data.DataSet,
    System.Xml.Serialization.IXmlSerializable,
    System.Runtime.Serialization.ISerializable,
    System.ComponentModel.IListSource,
    System.ComponentModel.ISupportInitialize,
    System.ComponentModel.IComponent,
):  # Class
    def __init__(self) -> None: ...

    BatchFiles: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesDataTable
    )  # readonly
    Relations: System.Data.DataRelationCollection  # readonly
    SchemaSerializationMode: System.Data.SchemaSerializationMode
    Tables: System.Data.DataTableCollection  # readonly

    @staticmethod
    def GetTypedDataSetSchema(
        xs: System.Xml.Schema.XmlSchemaSet,
    ) -> System.Xml.Schema.XmlSchemaComplexType: ...
    def Clone(self) -> System.Data.DataSet: ...

    # Nested Types

    class BatchFilesDataTable(
        System.IServiceProvider,
        System.ComponentModel.ISupportInitialize,
        Iterable[Any],
        System.ComponentModel.ISupportInitializeNotification,
        System.Xml.Serialization.IXmlSerializable,
        Iterable[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow
        ],
        System.ComponentModel.IComponent,
        System.Runtime.Serialization.ISerializable,
        System.ComponentModel.IListSource,
        System.IDisposable,
        System.Data.TypedTableBase[
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow
        ],
    ):  # Class
        def __init__(self) -> None: ...

        AnalysisTimestampColumn: System.Data.DataColumn  # readonly
        AuditTrailValidColumn: System.Data.DataColumn  # readonly
        Count: int  # readonly
        DataVersionColumn: System.Data.DataColumn  # readonly
        ErrorColumn: System.Data.DataColumn  # readonly
        FilePathColumn: System.Data.DataColumn  # readonly
        FileTypeColumn: System.Data.DataColumn  # readonly
        HashCodeValidColumn: System.Data.DataColumn  # readonly
        def __getitem__(
            self, index: int
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow
        ): ...
        LastWrittenTimeColumn: System.Data.DataColumn  # readonly
        MessagesColumn: System.Data.DataColumn  # readonly

        @overload
        def AddBatchFilesRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
        ) -> None: ...
        @overload
        def AddBatchFilesRow(
            self,
            FilePath: str,
            FileType: str,
            Error: bool,
            HashCodeValid: bool,
            AuditTrailValid: bool,
            DataVersion: int,
            AnalysisTimestamp: System.DateTime,
            LastWrittenTime: System.DateTime,
            Messages: str,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow
        ): ...
        def RemoveBatchFilesRow(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
        ) -> None: ...
        @staticmethod
        def GetTypedTableSchema(
            xs: System.Xml.Schema.XmlSchemaSet,
        ) -> System.Xml.Schema.XmlSchemaComplexType: ...
        def Clone(self) -> System.Data.DataTable: ...
        def NewBatchFilesRow(
            self,
        ) -> (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow
        ): ...

        BatchFilesRowChanged: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRowChangeEventHandler
        )  # Event
        BatchFilesRowChanging: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRowChangeEventHandler
        )  # Event
        BatchFilesRowDeleted: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRowChangeEventHandler
        )  # Event
        BatchFilesRowDeleting: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRowChangeEventHandler
        )  # Event

    class BatchFilesRow(System.Data.DataRow):  # Class
        AnalysisTimestamp: System.DateTime
        AuditTrailValid: bool
        DataVersion: int
        Error: bool
        FilePath: str
        FileType: str
        HashCodeValid: bool
        LastWrittenTime: System.DateTime
        Messages: str

        def IsFileTypeNull(self) -> bool: ...
        def SetErrorNull(self) -> None: ...
        def SetMessagesNull(self) -> None: ...
        def IsMessagesNull(self) -> bool: ...
        def SetLastWrittenTimeNull(self) -> None: ...
        def SetDataVersionNull(self) -> None: ...
        def IsHashCodeValidNull(self) -> bool: ...
        def IsAnalysisTimestampNull(self) -> bool: ...
        def IsErrorNull(self) -> bool: ...
        def SetHashCodeValidNull(self) -> None: ...
        def IsAuditTrailValidNull(self) -> bool: ...
        def SetAnalysisTimestampNull(self) -> None: ...
        def IsLastWrittenTimeNull(self) -> bool: ...
        def IsDataVersionNull(self) -> bool: ...
        def SetAuditTrailValidNull(self) -> None: ...
        def SetFileTypeNull(self) -> None: ...

    class BatchFilesRowChangeEvent(System.EventArgs):  # Class
        def __init__(
            self,
            row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
            action: System.Data.DataRowAction,
        ) -> None: ...

        Action: System.Data.DataRowAction  # readonly
        Row: (
            Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow
        )  # readonly

    class BatchFilesRowChangeEventHandler(
        System.MulticastDelegate,
        System.ICloneable,
        System.Runtime.Serialization.ISerializable,
    ):  # Class
        def __init__(self, object: Any, method: System.IntPtr) -> None: ...
        def EndInvoke(self, result: System.IAsyncResult) -> None: ...
        def BeginInvoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRowChangeEvent,
            callback: System.AsyncCallback,
            object: Any,
        ) -> System.IAsyncResult: ...
        def Invoke(
            self,
            sender: Any,
            e: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRowChangeEvent,
        ) -> None: ...

class CheckerBase(System.IDisposable):  # Class
    PathName: str  # readonly

    def Dispose(self) -> None: ...
    def ApplyResults(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...

    Complete: System.EventHandler  # Event
    Started: System.EventHandler  # Event

class CommandLine:  # Class
    def __init__(self) -> None: ...

    Culture: str
    Folders: List[str]
    Help: bool

class DirectoryChecker(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckerBase,
):  # Class
    def __init__(
        self,
        directory: str,
        recursive: bool,
        checkPicardSamples: bool,
        checkPicardMethods: bool,
        results: Dict[str, bool],
        abortHandle: System.Threading.WaitHandle,
    ) -> None: ...

    PathName: str  # readonly
    Recursive: bool  # readonly

    def Check(self) -> None: ...
    @staticmethod
    def IsBroncoMethodFolder(folder: str) -> bool: ...

    FileCheckComplete: System.EventHandler  # Event
    FileCheckStarted: System.EventHandler  # Event

class FileChecker(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckerBase,
):  # Class
    def __init__(
        self,
        file: str,
        fileType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType,
        abort: System.Threading.WaitHandle,
    ) -> None: ...

    PathName: str  # readonly
    Results: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResults
    )  # readonly

    def Check(self) -> None: ...
    def ApplyResults(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...

class FileType(System.IConvertible, System.IComparable, System.IFormattable):  # Struct
    AcqMethod: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    ) = ...  # static # readonly
    Batch: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    ) = ...  # static # readonly
    MethodFile: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    ) = ...  # static # readonly
    ReportResult: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    ) = ...  # static # readonly
    Sample: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    ) = ...  # static # readonly
    Study: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    ) = ...  # static # readonly
    Worklist: (
        Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType
    ) = ...  # static # readonly

class Formatter(System.IDisposable):  # Class
    def WriteFileCheck(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...
    def Dispose(self) -> None: ...

class GenericFormatter(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.Formatter,
):  # Class
    def __init__(self, writer: System.IO.TextWriter, closeOnDispose: bool) -> None: ...
    def WriteFileCheck(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...

class PicardFolderChecker(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckerBase,
):  # Class
    def __init__(
        self,
        folder: str,
        fileType: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.FileType,
        abort: System.Threading.WaitHandle,
    ) -> None: ...

    PathName: str  # readonly

    def Check(self) -> None: ...
    def ApplyResults(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...

class ResultsForm(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def Start(self) -> None: ...
    def AddFolders(self, folders: List[str]) -> None: ...

class SelectFolders(
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceObject,
    System.Windows.Forms.IWin32Window,
    System.Windows.Forms.Layout.IArrangedElement,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStreamInit,
    System.Windows.Forms.ISupportOleDropSource,
    System.Windows.Forms.IBindableComponent,
    System.Windows.Forms.IDropTarget,
    System.Windows.Forms.UnsafeNativeMethods.IPersistStorage,
    System.Windows.Forms.Form,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject2,
    System.Windows.Forms.UnsafeNativeMethods.IQuickActivate,
    System.Windows.Forms.IContainerControl,
    System.Windows.Forms.UnsafeNativeMethods.IPersistPropertyBag,
    System.Windows.Forms.UnsafeNativeMethods.IOleInPlaceActiveObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleWindow,
    System.ComponentModel.IComponent,
    System.Windows.Forms.UnsafeNativeMethods.IOleObject,
    System.Windows.Forms.UnsafeNativeMethods.IPersist,
    System.IDisposable,
    System.ComponentModel.ISynchronizeInvoke,
    System.Windows.Forms.UnsafeNativeMethods.IViewObject,
    System.Windows.Forms.UnsafeNativeMethods.IOleControl,
):  # Class
    def __init__(self) -> None: ...
    def SetSelectedFolders(self, folders: List[str]) -> None: ...
    def GetSelectedFolders(self) -> List[str]: ...

class TextFormatter(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.Formatter,
):  # Class
    def __init__(
        self, writer: System.IO.TextWriter, closeOnDispose: bool, delimiter: str
    ) -> None: ...
    def WriteFileCheck(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...

class UserSettings(ConfigurationElementSectionBase):  # Class
    def __init__(self) -> None: ...

    LastFolder: str

class XmlFormatter(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.Formatter,
):  # Class
    def __init__(self, writer: System.IO.TextWriter, closeOnDispose: bool) -> None: ...
    def WriteFileCheck(
        self,
        row: Agilent.MassSpectrometry.DataAnalysis.Quantitative.CheckBatchFiles.CheckResultsDataSet.BatchFilesRow,
    ) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from . import (
    Commands,
    Configurations,
    Controls,
    DataAccess,
    Remoting,
    ScriptIf,
    ScriptIfImpls,
    ToolHandlers,
    Utils,
)
from .Commands import AppContext
from .Controls import MainForm
from .Quantitative.Compliance import ICompliance
from .Utils import CompoundKey, SpectrumKey

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.LibraryEdit

class CommandLine:  # Class
    def __init__(self) -> None: ...

    AccountName: str
    CommandLog: str
    ConnectionTicket: str
    Console: bool
    Culture: str
    Domain: str
    EncryptedPassword: str
    Help: bool
    Library: str
    Password: str
    ScriptFiles: List[str]
    Server: str
    User: str

    def Initialize(self, compliance: ICompliance) -> MainForm: ...
    def SetCulture(self) -> None: ...
    def InitCompliance(self, mainForm: MainForm) -> bool: ...
    def RunScripts(self, form: MainForm) -> bool: ...
    def Run(self, form: MainForm) -> None: ...

class ConsoleCommandLine:  # Class
    def __init__(self) -> None: ...

    AccountName: str
    ConnectionTicket: str
    Culture: str
    Domain: str
    EncryptedPassword: str
    Help: bool
    NoLogo: bool
    Password: str
    ScriptFiles: List[str]
    Server: str
    User: str

    def Run(self, compliance: ICompliance) -> int: ...

class Definitions:  # Class
    JcampFileExtension: str = ...  # static # readonly
    NormalizedAbundance: float = ...  # static # readonly

    BinaryFileExtension: str  # static # readonly
    CompressedLibraryExtension: str  # static # readonly
    PatternRefLibraryExtension: str  # static # readonly
    RefLibraryExtension: str  # static # readonly
    XmlFileExtension: str  # static # readonly

class LibraryEditException(
    System.Runtime.InteropServices._Exception,
    System.Runtime.Serialization.ISerializable,
    System.Exception,
):  # Class
    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, message: str) -> None: ...
    @overload
    def __init__(
        self, ci: System.Globalization.CultureInfo, format: str, parameters: List[Any]
    ) -> None: ...
    @overload
    def __init__(self, message: str, innerException: System.Exception) -> None: ...

class UIContext(System.IDisposable):  # Class
    def __init__(self, compliance: ICompliance) -> None: ...

    AppContext: AppContext  # readonly
    SelectedCompoundCount: int  # readonly
    SelectedCompoundKeys: Iterable[CompoundKey]  # readonly
    SelectedSpectrumCount: int  # readonly
    SelectedSpectrumKeys: Iterable[SpectrumKey]  # readonly

    def ClearCompoundSelection(self) -> None: ...
    def SelectSpectra(self, keys: Iterable[SpectrumKey]) -> None: ...
    def Dispose(self) -> None: ...
    def SelectCompounds(self, keys: Iterable[CompoundKey]) -> None: ...



# -*- coding: utf-8 -*-
import typing

# Import specific members from typing used in hints
from typing import (
    Any,
    Callable,
    Dict,
    FrozenSet,
    Generic,
    Iterable,
    Iterator,
    List,
    Mapping,
    Optional,
    Sequence,
    Set,
    Tuple,
    TypeVar,
    Union,
    overload,
)

import datetime
from enum import Enum

from mh_operator.SDK import Agilent, System

from .Command import KeyValue
from .DataFile import DataFileBase, TransactionBase

# Stubs for namespace: Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand

class AddAuxiliaryMethod(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(self, dataFile: DataFileBase, batchID: int, sampleID: int) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddBatch(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(self, dataFile: DataFileBase, batchID: int) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddBlankSubtractionMethod(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        blankSubtractionMethodID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddComponent(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        values: List[KeyValue],
    ) -> None: ...

    TableName: str  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class AddDeconvolutionMethod(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddExactMass(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        exactMassID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddHit(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddIdentificationMethod(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        identificationMethodID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddIonPeak(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        ionPeakID: int,
        values: List[KeyValue],
    ) -> None: ...

    TableName: str  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class AddLibrarySearchMethod(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        identificationMethodID: int,
        librarySearchMethodID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddPeak(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        compoundID: int,
        peakID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddPeakQualifier(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        compoundID: int,
        qualifierID: int,
        peakID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddRow(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    Reversible: bool  # readonly
    TableName: str  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def SetColumn(self, name: str, value_: Any) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...

class AddSample(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(self, dataFile: DataFileBase, batchID: int, sampleID: int) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddTargetCompound(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self, dataFile: DataFileBase, batchID: int, sampleID: int, compoundID: int
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddTargetMatchMethod(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        targetMatchMethodID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class AddTargetQualifier(
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.AddRow,
    System.IDisposable,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        compoundID: int,
        qualifierID: int,
    ) -> None: ...

    TableName: str  # readonly

    def Undo(self, transaction: TransactionBase) -> None: ...

class DataCommandBase(System.IDisposable):  # Class
    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def Dispose(self) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class RemoveLibrarySearchMethod(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        identificationMethodID: int,
        librarySearchMethodID: int,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class RemoveTargetCompound(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self, dataFile: DataFileBase, batchID: int, sampleID: int, compoundID: int
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class SetComponent(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def SetValue(self, name: str, value_: Any) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class SetExactMass(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        exactMassID: int,
        name: str,
        value_: Any,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class SetHit(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        hitID: int,
        name: str,
        value_: Any,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class SetIonPeak(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        deconvolutionMethodID: int,
        componentID: int,
        ionPeakID: int,
        name: str,
        value_: Any,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class SetSample(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self,
        dataFile: DataFileBase,
        batchID: int,
        sampleID: int,
        name: str,
        value_: Any,
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...

class SetTargetCompound(
    System.IDisposable,
    Agilent.MassSpectrometry.DataAnalysis.UnknownsAnalysisII.DataCommand.DataCommandBase,
):  # Class
    def __init__(
        self, dataFile: DataFileBase, batchID: int, sampleID: int, compoundID: int
    ) -> None: ...

    Reversible: bool  # readonly

    def Do(self, transaction: TransactionBase) -> None: ...
    def Redo(self, transaction: TransactionBase) -> None: ...
    def SetValue(self, name: str, value_: Any) -> None: ...
    def Undo(self, transaction: TransactionBase) -> None: ...
